HealthCheck enum
A health check the engine may abort a run over.
Values
- filterTooMuch → const HealthCheck
-
Too many draws rejected by assumptions.
const HealthCheck(raw.hegel_health_check_t.HEGEL_HC_FILTER_TOO_MUCH) - tooSlow → const HealthCheck
-
Individual test cases taking too long.
const HealthCheck(raw.hegel_health_check_t.HEGEL_HC_TOO_SLOW) - testCasesTooLarge → const HealthCheck
-
Generated values too large.
const HealthCheck(raw.hegel_health_check_t.HEGEL_HC_TEST_CASES_TOO_LARGE) - largeInitialTestCase → const HealthCheck
-
A first test case that is already disproportionately large.
const HealthCheck(raw.hegel_health_check_t.HEGEL_HC_LARGE_INITIAL_TEST_CASE)
Properties
- bit → int
-
This value's bit.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
HealthCheck> - A constant List of the values in this enum, in order of their declaration.